@@ -30,7 +30,7 @@
     (lambda (obj)
       (cond ((mock? obj)
 	     (let-temporarily (((*s7* 'openlets) #f))
-	       (func (obj 'value))))
+	       (func (let-ref obj 'value))))
 
 	    ((not (openlet? obj))
 	     (func obj))
@@ -47,12 +47,16 @@
 
   (define (with-mock-wrapper* func)
     (lambda args
+      ;(format *stderr* "with-mock-wrapper ~S~%" args)
       (let ((unknown-openlets #f)
-	    (new-args ()))
+	    (new-args ())
+	    (got-mock #f))
 	(for-each (lambda (arg) ; not map here because (values) should not be ignored: (+ (mock-number 4/3) (values))
 		    (set! new-args
 			  (cons (if (mock? arg)
-				    (arg 'value)
+				    (begin
+				      (set! got-mock #t)
+				      (arg 'value))
 				    (begin
 				      (if (and (openlet? arg)
 					       (not (procedure? arg))
@@ -62,7 +66,7 @@
 				      arg))
 				new-args)))
 		  args)
-	(if unknown-openlets
+	(if (and unknown-openlets got-mock)
 	    (apply func (reverse! new-args))
 	    (let-temporarily (((*s7* 'openlets) #f)) 
 	      (apply func (reverse! new-args)))))))
@@ -80,13 +84,13 @@
 						 (error 'wrong-type-arg "stray mock-vector? ~S" i))
 					     (#_vector-set! (->value obj) i val))
 		       
-		       'vector-set!        (lambda (obj i val) ((obj 'local-set!) obj i val) val)
+		       'vector-set!        (lambda (obj i val) ((let-ref obj 'local-set!) obj i val) val)
 		       
 		       'let-set-fallback   (lambda (obj i val) 
 					     (if (and (integer? i)
 						      (defined? 'value obj))
 						 (begin
-						   ((obj 'local-set!) obj i val) 
+						   ((let-ref obj 'local-set!) obj i val) 
 						   val)
 						 (error 'out-of-range "unknown field: ~S" i)))
 		       
@@ -127,6 +131,7 @@
 		       'length             (with-mock-wrapper #_length)
 		       'vector-append      (with-mock-wrapper* #_vector-append)
 		       'append             (with-mock-wrapper* #_append)
+		       'vector-typer       (with-mock-wrapper #_vector-typer)
 		       'class-name         '*mock-vector*)))
 	  
 	  (define (make-mock-vector len . rest)
@@ -223,6 +228,8 @@
 		       'hash-table?        (with-mock-wrapper #_hash-table?)
 		       'length             (with-mock-wrapper #_length)
 		       'append             (with-mock-wrapper* #_append)
+		       'hash-table-key-typer (with-mock-wrapper #_hash-table-key-typer)
+		       'hash-table-value-typer (with-mock-wrapper #_hash-table-value-typer)
 		       'class-name         '*mock-hash-table*)))
 	  
 	  (define (make-mock-hash-table . rest)
@@ -264,7 +271,7 @@
 			  (#_hash-table-ref (obj 'value) key)))))
   
   (define (hash-table-key? obj key) 
-    ((obj 'hash-table-key?) obj key))
+    ((let-ref obj 'hash-table-key?) obj key))
   
   (define* (make-gloomy-hash-table (len 511) not-a-key)
     (let ((ht (gloomy-hash-table)))
