@@ -124,12 +124,18 @@
 	 (c (read-byte pt) (read-byte pt)))
 	((or (>= i lim)
 	     (eof-object? c))
-	 (if (< i lim)
-	     (copy (subvector bv 0 i))
-	     bv))
+	 (if (= i start) #<eof> (- i start))) ; or i?
       (set! (bv i) c))))
 
-(define* (read-bytevector k port) (read-bytevector! (make-byte-vector k) port))
+(define* (read-bytevector k port)
+  (let* ((buf (make-byte-vector k))
+	 (bytes (read-bytevector! buf port)))
+    (if (eof-object? bytes)
+	bytes
+	(if (= k bytes)
+	    buf
+	    (subvector buf 0 bytes)))))
+
 (define (get-output-bytevector port) (string->byte-vector (get-output-string port)))
 (define (open-input-bytevector bv) (open-input-string (copy bv (make-string (length bv)))))
 (define open-output-bytevector open-output-string)
@@ -237,10 +243,14 @@
 					   (values ,@(map (lambda (name)
 							    (values (symbol->keyword name) name))
 							  (let args->proper-list ((args (car v)))
-							    (cond ((symbol? args)	(list args))
-								  ((not (pair? args))	args)
-								  ((pair? (car args))	(cons (caar args) (args->proper-list (cdr args))))
-								  (else                 (cons (car args) (args->proper-list (cdr args)))))))))
+							    (cond ((symbol? args)	
+								   (list args))
+								  ((not (pair? args))	
+								   args)
+								  ((pair? (car args))	
+								   (cons (caar args) (args->proper-list (cdr args))))
+								  (else                 
+								   (cons (car args) (args->proper-list (cdr args)))))))))
 					 ,(cadr v)))
 				     vars)))
 	 ,@body)))
@@ -437,15 +447,14 @@
 ;; and why no euclidean-rationalize or exact-integer-expt?
 ;;   (imagine what will happen when r8rs stumbles on the zoo of continued fraction algorithms!)
 
-(define (jiffies-per-second) 1000)
-(define (current-jiffy) (round (* (jiffies-per-second) (*s7* 'cpu-time))))
-(define (current-second) (floor (*s7* 'cpu-time)))
+(define (jiffies-per-second) 1000000000)
+(define (current-jiffy)
+  (with-let *libc*
+    (let ((res (clock_gettime CLOCK_REALTIME)))
+      (+ (* 1000000000 (cadr res)) (caddr res)))))
+(define (current-second) (* 1.0 ((*libc* 'time) (c-pointer 0 'time_t*))))
 
-(define (get-environment-variable x)
-  (let ((val ((*libc* 'getenv) x)))
-    (and (string? val)
-	 (> (length val) 0)
-	 val)))
+(define get-environment-variable getenv)
 (define get-environment-variables (*libc* 'getenvs))
 (define (r7rs-file-exists? arg) (= ((*libc* 'access) arg (*libc* 'F_OK)) 0))
 (define r7rs-delete-file (*libc* 'unlink))
