@@ -71,8 +71,8 @@
 (define max-lspher 0)
 (define max-osc 0)
 (define max-lchrom 0)
-(define radius-of-curvature 0)
-(define object-distance 0)
+(define radius-of-curvature 0.0)
+(define object-distance 0.0)
 (define ray-height 0)
 (define axis-slope-angle 0)
 (define from-index 0)
@@ -117,30 +117,30 @@
 (define (transit-surface)
   (let ((iang-sin 0))
     (if (= paraxial 1)
-	(if (zero? radius-of-curvature)
+	(if (= radius-of-curvature 0.0)
 	    (begin
 	      (set! object-distance (* object-distance (/ to-index from-index)))
 	      (set! axis-slope-angle (* axis-slope-angle (/ from-index to-index))))
 	    (begin
-	      (if (zero? object-distance)
+	      (if (= object-distance 0.0)
 		  (begin
-		    (set! axis-slope-angle 0)
+		    (set! axis-slope-angle 0.0)
 		    (set! iang-sin (/ ray-height radius-of-curvature)))
 		  (set! iang-sin (* (/ (- object-distance radius-of-curvature) radius-of-curvature) axis-slope-angle)))
 	      (let ((rang-sin (* (/ from-index to-index) iang-sin))
 		    (old-axis-slope-angle axis-slope-angle))
 		(set! axis-slope-angle (- (+ axis-slope-angle iang-sin) rang-sin))
-		(if (not (zero? object-distance))
+		(if (not (= object-distance 0.0))
 		    (set! ray-height (* object-distance old-axis-slope-angle)))
 		(set! object-distance (/ ray-height axis-slope-angle)))))
-	(if (zero? radius-of-curvature)
+	(if (= radius-of-curvature 0.0)
 	    (let ((rang (- (asin (* (/ from-index to-index) (sin axis-slope-angle))))))
 	      (set! object-distance (/ (* object-distance to-index (cos rang)) (* from-index (cos axis-slope-angle))))
 	      (set! axis-slope-angle (- rang)))
 	    (begin
-	      (if (zero? object-distance)
+	      (if (= object-distance 0.0)
 		  (begin
-		    (set! axis-slope-angle 0)
+		    (set! axis-slope-angle 0.0)
 		    (set! iang-sin (/ ray-height radius-of-curvature)))
 		  (set! iang-sin (* (/ (- object-distance radius-of-curvature) radius-of-curvature) (sin axis-slope-angle))))
 	      (let ((iang (asin iang-sin))
@@ -148,12 +148,12 @@
 		    (old-axis-slope-angle axis-slope-angle))
 		(set! axis-slope-angle (+ axis-slope-angle (- iang (asin rang-sin))))
 		(let ((sagitta (sin (/ (+ old-axis-slope-angle iang) 2.0))))
-		  (set! sagitta (* 2 radius-of-curvature sagitta sagitta))
+		  (set! sagitta (* (* 2 radius-of-curvature) (* sagitta sagitta)))
 		  (set! object-distance (+ (/ (* radius-of-curvature (sin (+ old-axis-slope-angle iang))) (tan axis-slope-angle)) sagitta)))))))))
 
 ;;	Perform ray trace in specific spectral line
 (define (trace-line line ray-h)
-  (set! object-distance 0)
+  (set! object-distance 0.0)
   (set! ray-height ray-h)
   (set! from-index 1)
   (for-each (lambda (surface)
