@@ -123,12 +123,6 @@
 			(autotest func c-args1 args-now1 args-left1 sig1))
 		      auto-constants)))))))))
   
-  (define safe-fill!
-    (let ((+signature+ '(#t sequence? #t)))
-      (lambda (obj arg)
-	(if (not (let? obj))
-	    (fill! obj arg)))))
-  
   (define (map-values lst)
     (do ((lst lst (cdr lst)))
 	((or (not (pair? lst))
@@ -205,12 +199,11 @@
       (outputters '(write display write-string write-char write-byte newline))
       (even-args '(hash-table weak-hash-table)))
   
-  (define (type-ok probe targets)
-    (let type-ok ((types targets))
-      (and (pair? types)
-	   (or (memq (car types) '(#t values))
-	       ((symbol->value (car types)) probe)
-	       (type-ok (cdr types))))))
+  (define (type-ok probe types)
+    (and (pair? types)
+	 (or (memq (car types) '(#t values))
+	     ((symbol->value (car types)) probe)
+	     (type-ok probe (cdr types)))))
   
   (define (check sym)
     (let ((func (symbol->value sym)))
@@ -219,9 +212,8 @@
 	(let ((ari (arity func))
 	      (sig (signature func))
 	      (doc (documentation func)))
-	  (if (and (string? doc) 
-		   (not (string=? doc ""))
-		   (not (string-position (symbol->string sym) doc)))
+	  (unless (or (string=? doc "")
+		      (string-position (symbol->string sym) doc))
 	      (format *stderr* "~A documentation does not mention it: ~S~%" sym doc))
 	  (when (pair? sig)
 	    (let ((res-types (if (pair? (car sig)) (car sig) (list (car sig)))))
