@@ -14,7 +14,7 @@
     (do ((i 0 (+ i 1)))
 	((= i tries))
       (let ((p1 (cons 1 2))
-	    (p2 (list 1 1 1 1 1 1 1))
+	    (p2 (make-list 7 1))
 	    (p3 (list 1 2)))
 	(set-cdr! (cdr p3) p3)
 	(check-cyclic p1)
