@@ -250,11 +250,11 @@
 (define (mv8)
   (+ (values 1 2 3) (values 3 -2 -1)))
 (define (mv9)
-  (+ (abs -1) (values 2 3 4) -4))
+  (+ 1 (values 2 3 4) -4))
 (define (mv10)
   (+ (values 1 2 3)))
 (define (mv11)
-  (+ (abs -1) (values -1 2 4)))
+  (+ 1 (values -1 2 4)))
 (define (mv12 x y)
   (+ x y (values 2 3 4)))
 
@@ -386,22 +386,22 @@
 
 (unless (provided? 'pure-s7)
 
-  (define (m5)
-    (let ((L (openlet (inlet :length (lambda (str) (+ 2 (#_string-length "asdfghjklijk")))))))
+  (define (m5 str)
+    (let ((L (openlet (inlet :length (lambda (s) (+ 2 (#_string-length str)))))))
       (do ((i 0 (+ i 1)))
 	  ((= i 1000000) (length L))
 	(length L))))
   
-  (unless (eqv? (m5) 14) (format *stderr* "m5: ~S~%" (m5)))
+  (unless (eqv? (m5 "asdfghjklijk") 14) (format *stderr* "m5: ~S~%" (m5 "asdfghjklijk")))
   
-  (define (m6)
-    (let ((L (openlet (inlet :length (lambda (str) (+ 2 (#_string-length str)))))))
+  (define (m6 str)
+    (let ((L (openlet (inlet :str str :length (lambda (s) (+ 2 (#_string-length s)))))))
       (do ((i 0 (+ i 1)))
-	  ((= i 1000000) (with-let L (length "asdfghjklijk")))
+	  ((= i 1000000) (with-let L (length str)))
 	(with-let L
-	  (length "asdfghjklijk")))))
+	  (length str)))))
   
-  (unless (eqv? (m6) 14) (format *stderr* "m6: ~S~%" (m6))))
+  (unless (eqv? (m6 "asdfghjklijk") 14) (format *stderr* "m6: ~S~%" (m6 "asdfghjklijk"))))
 
 (define (m7)
   (let ((L (openlet (inlet :+ (lambda (x y) (#_+ x y 1))))))
