@@ -96,7 +96,7 @@
 	(sum 0))
     (do ((i 0 (+ i 1)))
 	((= i size) sum)
-      (set! sum (+ sum (if (vector-ref v i) 1 0))))))
+      (if (vector-ref v i) (set! sum (+ sum 1))))))
 
 (unless (= (f6) size)
   (format *stderr* "f6: ~S~%" (f6)))
@@ -175,7 +175,7 @@
 	((= k 10) sum)
       (do ((i 0 (+ i 1)))
 	  ((= i size/10))
-	(set! sum (+ sum (if (eq? 'a (vector-ref v k i)) 1 0)))))))
+	(if (eq? 'a (vector-ref v k i)) (set! sum (+ sum 1)))))))
 
 (unless (= (f16) size)
   (format *stderr* "f16: ~S~%" (f15)))
@@ -244,7 +244,8 @@
 	(sum 0))
     (do ((i 0 (+ i 1)))
 	((= i size) sum)
-      (set! sum (+ sum (if (zero? (real-part (vector-ref v i))) 1 0)))))) ; faster is (imag-part...)
+      (if (zero? (real-part (vector-ref v i))) ; faster is (imag-part...)
+	  (set! sum (+ sum 1))))))
 
 (unless (= (g6) size)
   (format *stderr* "g6: ~S~%" (g6)))
@@ -324,7 +325,8 @@
 	((= k 10) sum)
       (do ((i 0 (+ i 1)))
 	  ((= i size/10))
-	(set! sum (+ sum (if (char=? (vector-ref v k i) #\a) 1 0)))))))
+	(if (char=? (vector-ref v k i) #\a) 
+	    (set! sum (+ sum 1)))))))
 
 (unless (= (g16) size)
   (format *stderr* "g16: ~S~%" (g16)))
@@ -722,9 +724,11 @@
 	((= k size3) v)
       (do ((i 0 (+ i 1)))
 	  ((= i size3))
-	(do ((n 0 (+ n 1)))
+	(do ((k3 (* k size3 size3))
+	     (i3 (* i size3))
+	     (n 0 (+ n 1)))
 	    ((= n size3))
-	  (vector-set! v k i n (+ (* i size3) (* k size3 size3) n)))))))
+	  (vector-set! v k i n (+ i3 k3 n)))))))
 
 (define (sum-h1111)
   (let ((sum 0)
@@ -747,9 +751,11 @@
 	((= k size3) v)
       (do ((i 0 (+ i 1)))
 	  ((= i size3))
-	(do ((n 0 (+ n 1)))
+	(do ((k3 (* k size3 size3))
+	     (i3 (* i size3))
+	     (n 0 (+ n 1)))
 	    ((= n size3))
-	  (int-vector-set! v k i n (+ (* i size3) (* k size3 size3) n)))))))
+	  (int-vector-set! v k i n (+ i3 k3 n)))))))
 
 (define (sum-i1111)
   (let ((sum 0)
@@ -772,9 +778,11 @@
 	((= k size3) v)
       (do ((i 0 (+ i 1)))
 	  ((= i size3))
-	(do ((n 0 (+ n 1)))
+	(do ((k3 (* k size3 size3))
+	     (i3 (* i size3))
+	     (n 0 (+ n 1)))
 	    ((= n size3))
-	  (float-vector-set! v k i n (+ 0.0 (* i size3) (* k size3 size3) n)))))))
+	  (float-vector-set! v k i n (+ 0.0 i3 k3 n)))))))
 
 (define (sum-f1111)
   (let ((sum 0.0)
@@ -791,12 +799,12 @@
   (format *stderr* "f1111: ~S~%" (sum-f1111)))
 
 (define (vcop a b n)
-  (let ((c (do ((i (- n 1) (- i 1)))
-	       ((< i 0) b)
-	     (vector-set! b i (vector-ref a i)))))
-    (do ((i 0 (+ i 1)))
-	((= i n) a)
-      (vector-set! a i (vector-ref b i)))))
+  (do ((i (- n 1) (- i 1)))
+      ((< i 0) b)
+    (vector-set! b i (vector-ref a i)))
+  (do ((i 0 (+ i 1)))
+      ((= i n) a)
+    (vector-set! a i (vector-ref b i))))
 
 (define (tvcop)
   (do ((k 0 (+ k 1)))
